@@ -14,21 +14,13 @@
 
 import numpy as np
 import pandas as pd
-from .exceptions import InsufficientData, MoonchartError
-from .utils import (
-    get_zscores,
-    trim_outliers as trim_outliers_func,
-    get_sharpe,
-    get_rolling_sharpe,
-    get_cagr,
-    get_cum_returns,
-    get_drawdowns,
-    intraday_to_daily,
-    get_average_holding_periods,
-    get_top_movers)
 
-from quantrocket.moonshot import read_moonshot_csv
 from quantrocket.blotter import read_pnl_csv
+from quantrocket.moonshot import read_moonshot_csv
+
+from .utils import *
+from .utils import trim_outliers as trim_outliers_func
+from .exceptions import InsufficientData, MoonchartError
 
 
 class DailyPerformance(object):
@@ -106,7 +98,7 @@ class DailyPerformance(object):
                 "Moonchart needs at least 2 dates to analyze performance, "
                 "but returns DataFrame has length {0}".format(len(self.returns.index)))
         self._trim_outliers = trim_outliers
-        if trim_outliers:
+        if self._trim_outliers:
             self.returns = trim_outliers_func(returns, z_score=trim_outliers)
         else:
             # warn the user if there are >10-sigma returns
@@ -143,8 +135,10 @@ class DailyPerformance(object):
         self._drawdowns = None
         self._max_drawdown = None
         self._cum_pnl = None
-        self._average_holding_periods = None
+        self._average_holding_periods_pos = None
+        self._average_holding_periods_null = None
         self._top_movers = None
+        self._bar_size = None
 
     @classmethod
     def _from_moonshot_or_pnl(cls, results,
@@ -450,11 +444,18 @@ class DailyPerformance(object):
         return self._benchmark_cum_returns
 
     @property
-    def average_holding_periods(self):
-        if self._average_holding_periods is None:
-            self._average_holding_periods = get_average_holding_periods(self.total_holdings)
+    def average_holding_periods_pos(self):
+        if self._average_holding_periods_pos is None:
+            self._average_holding_periods_pos = get_average_holding_periods(self.total_holdings)
 
-        return self._average_holding_periods
+        return self._average_holding_periods_pos
+
+    @property
+    def average_holding_periods_null(self):
+        if self._average_holding_periods_null is None:
+            self._average_holding_periods_null = get_average_holding_periods(self.total_holdings, lambda x: x == 0)
+
+        return self._average_holding_periods_null
 
     @property
     def top_movers(self):
@@ -463,6 +464,13 @@ class DailyPerformance(object):
 
         return self._top_movers
 
+    @property
+    def bar_size(self):
+        if self._bar_size is None:
+            self._bar_size = get_bar_size(self.returns)
+
+        return self._bar_size
+
 
 class AggregateDailyPerformance(DailyPerformance):
     """
