@@ -323,7 +323,9 @@ class Tearsheet(BaseTearsheet):
 
         if agg_performance.total_holdings is not None:
             stats.append(["", " Average Holding Periods"])
-            for index, (v_min, v_max, v_avg) in performance.average_holding_periods.sort_index().iterrows():
+            for index, (v_min, v_max, v_avg) in performance.average_holding_periods_pos \
+                    .sort_values("Avg", ascending=False) \
+                    .iloc[:3].sort_index().iterrows():
                 stats.append(["Average Holding Period {} - Avg".format(index), round(v_avg)])
 
         with sns.axes_style("white"):
@@ -479,22 +481,25 @@ class Tearsheet(BaseTearsheet):
         if num_series > 6:
             color_palette = sns.color_palette("hls", num_series)
 
-        with sns.color_palette(color_palette):
-            top_movers = performance.top_movers
-            top_winners = top_movers[top_movers > 0].sort_index()
-            top_losers = top_movers[top_movers < 0].sort_index()
+        top_movers = performance.top_movers
+        top_winners = top_movers[top_movers > 0].sort_index()
+        top_losers = top_movers[top_movers < 0].sort_index()
 
+        with sns.color_palette(sns.light_palette("red")):
             axis = fig.add_subplot(2, 2, 1)
             axis.set_ylabel("Losses")
             self._y_format_as_percentage(axis)
-            loss = top_losers.copy()
-            loss.unstack().plot(ax=axis, kind="bar", title="Biggest Losers", color=["r"])
+            loss = top_losers.copy().unstack()
+            ax = loss.plot(ax=axis, kind="bar", title="Biggest Losers")
+            ax.xaxis.set_major_formatter(plt.FixedFormatter(loss.index.to_series().dt.strftime("%Y-%m-%d")))
 
+        with sns.color_palette(sns.light_palette("green")):
             axis = fig.add_subplot(2, 2, 2)
             axis.set_ylabel("Wins")
             self._y_format_as_percentage(axis)
-            win = top_winners.copy()
-            win.unstack().plot(ax=axis, kind="bar", title="Biggest Winners", color=["g"])
+            win = top_winners.copy().unstack()
+            ax = win.plot(ax=axis, kind="bar", title="Biggest Winners")
+            ax.xaxis.set_major_formatter(plt.FixedFormatter(win.index.to_series().dt.strftime("%Y-%m-%d")))
 
         fig.tight_layout()
 
@@ -637,6 +642,8 @@ class Tearsheet(BaseTearsheet):
             performance.total_holdings,
             performance.turnover,
             performance.abs_exposures) if field is not None])
+        if performance.total_holdings is not None:
+            total_plots += 2
 
         rows = math.ceil(total_plots / 2)
 
@@ -686,9 +693,16 @@ class Tearsheet(BaseTearsheet):
             if performance.total_holdings is not None:
                 axis = fig.add_subplot(rows, 2, next_pos)
                 next_pos += 1
-                holding_periods = performance.average_holding_periods
-                holding_periods.plot(ax=axis, kind="bar", title="Average Holding Period")
-                axis.set_ylabel("Bars")
+                holding_periods_pos = performance.average_holding_periods_pos
+                holding_periods_pos.plot(ax=axis, kind="bar", title="Average Holding Period")
+                axis.set_ylabel("Bars ({})".format(performance.bar_size.time_string()))
+
+                holding_periods_null = performance.average_holding_periods_null
+                if holding_periods_null is not None:
+                    axis = fig.add_subplot(rows, 2, next_pos)
+                    next_pos += 1
+                    holding_periods_null.plot(ax=axis, kind="bar", title="Average Holding Period in Cash")
+                    axis.set_ylabel("Bars ({})".format(performance.bar_size.time_string()))
 
         fig.tight_layout()
 
